@@ -11,7 +11,7 @@ Authorization Server / Resource Server with Mojolicious
 
 =head1 VERSION
 
-0.37
+0.38
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ use Mojo::Util qw/ b64_decode /;
 use Net::OAuth2::AuthorizationServer;
 use Carp qw/ croak /;
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 my ( $AuthCodeGrant,$PasswordGrant,$ImplicitGrant,$ClientCredentialsGrant,$Grant,$JWTCallback );
 
@@ -509,7 +509,7 @@ sub _client_credentials_from_header {
 
   if ( my $auth_header = $self->req->headers->header( 'Authorization' ) ) {
     if ( my ( $encoded_details ) = ( split( 'Basic ',$auth_header ) )[1] ) {
-      my $decoded_details = b64_decode( $encoded_details );
+      my $decoded_details = b64_decode( $encoded_details // '' );
       my ( $client_id,$client_secret ) = split( ':',$decoded_details );
       return ( $client_id,$client_secret );
     }
@@ -558,7 +558,7 @@ sub _verify_credentials {
       scopes          => $scope,
     );
 
-    undef( $client_id ) if ! $res;
+    undef( $client ) if ! $res;
 
   } else {
     ( $client,$error,$scope,$user_id ) = $Grant->verify_auth_code(
